==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/dbformysql/kotlin/DatabaseArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.dbformysql.kotlin

import com.pulumi.azurenative.dbformysql.DatabaseArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Represents a Database.
 * Azure REST API version: 2022-01-01. Prior API version in Azure Native 1.x: 2017-12-01.
 * Other available API versions: 2017-12-01, 2023-06-01-preview, 2023-06-30.
 * ## Example Usage
 * ### Create a database
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var database = new AzureNative.DBforMySQL.Database("database", new()
 *     {
 *         Charset = "utf8",
 *         Collation = "utf8_general_ci",
 *         DatabaseName = "db1",
 *         ResourceGroupName = "TestGroup",
 *         ServerName = "testserver",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/dbformysql/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := dbformysql.NewDatabase(ctx, "database", &dbformysql.DatabaseArgs{
 * 			Charset:           pulumi.String("utf8"),
 * 			Collation:         pulumi.String("utf8_general_ci"),
 * 			DatabaseName:      pulumi.String("db1"),
 * 			ResourceGroupName: pulumi.String("TestGroup"),
 * 			ServerName:        pulumi.String("testserver"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.dbformysql.Database;
 * import com.pulumi.azurenative.dbformysql.DatabaseArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var database = new Database("database", DatabaseArgs.builder()
 *             .charset("utf8")
 *             .collation("utf8_general_ci")
 *             .databaseName("db1")
 *             .resourceGroupName("TestGroup")
 *             .serverName("testserver")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:dbformysql:Database db1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DBforMySQL/flexibleServers/{serverName}/databases/{databaseName}
 * ```
 * @property charset The charset of the database.
 * @property collation The collation of the database.
 * @property databaseName The name of the database.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property serverName The name of the server.
 */
public data class DatabaseArgs(
    public val charset: Output<String>? = null,
    public val collation: Output<String>? = null,
    public val databaseName: Output<String>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val serverName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.dbformysql.DatabaseArgs> {
    override fun toJava(): com.pulumi.azurenative.dbformysql.DatabaseArgs =
        com.pulumi.azurenative.dbformysql.DatabaseArgs.builder()
            .charset(charset?.applyValue({ args0 -> args0 }))
            .collation(collation?.applyValue({ args0 -> args0 }))
            .databaseName(databaseName?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .serverName(serverName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DatabaseArgs].
 */
@PulumiTagMarker
public class DatabaseArgsBuilder internal constructor() {
    private var charset: Output<String>? = null

    private var collation: Output<String>? = null

    private var databaseName: Output<String>? = null

    private var resourceGroupName: Output<String>? = null

    private var serverName: Output<String>? = null

    /**
     * @param value The charset of the database.
     */
    @JvmName("gtjdrjsontcmkjqq")
    public suspend fun charset(`value`: Output<String>) {
        this.charset = value
    }

    /**
     * @param value The collation of the database.
     */
    @JvmName("pnrqudhhchxumipb")
    public suspend fun collation(`value`: Output<String>) {
        this.collation = value
    }

    /**
     * @param value The name of the database.
     */
    @JvmName("awlnxemomxfexseh")
    public suspend fun databaseName(`value`: Output<String>) {
        this.databaseName = value
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("fbpoubtoxfehffyr")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value The name of the server.
     */
    @JvmName("eqsedowlngejtuht")
    public suspend fun serverName(`value`: Output<String>) {
        this.serverName = value
    }

    /**
     * @param value The charset of the database.
     */
    @JvmName("ymjrktuiicbygeby")
    public suspend fun charset(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.charset = mapped
    }

    /**
     * @param value The collation of the database.
     */
    @JvmName("euyhoqawjgwwfaiq")
    public suspend fun collation(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.collation = mapped
    }

    /**
     * @param value The name of the database.
     */
    @JvmName("posavlqqbsuchhcf")
    public suspend fun databaseName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.databaseName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("voyypfjoxldwaetu")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the server.
     */
    @JvmName("yduhhljtcoaocphs")
    public suspend fun serverName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serverName = mapped
    }

    internal fun build(): DatabaseArgs = DatabaseArgs(
        charset = charset,
        collation = collation,
        databaseName = databaseName,
        resourceGroupName = resourceGroupName,
        serverName = serverName,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/dbformysql/kotlin/DatabaseArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.dbformysql.kotlin

import com.pulumi.azurenative.dbformysql.DatabaseArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Represents a Database.
 * Azure REST API version: 2022-01-01. Prior API version in Azure Native 1.x: 2017-12-01.
 * Other available API versions: 2017-12-01, 2023-06-01-preview, 2023-06-30.
 * ## Example Usage
 * ### Create a database
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var database = new AzureNative.DBforMySQL.Database("database", new()
 *     {
 *         Charset = "utf8",
 *         Collation = "utf8_general_ci",
 *         DatabaseName = "db1",
 *         ResourceGroupName = "TestGroup",
 *         ServerName = "testserver",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/dbformysql/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := dbformysql.NewDatabase(ctx, "database", &dbformysql.DatabaseArgs{
 * 			Charset:           pulumi.String("utf8"),
 * 			Collation:         pulumi.String("utf8_general_ci"),
 * 			DatabaseName:      pulumi.String("db1"),
 * 			ResourceGroupName: pulumi.String("TestGroup"),
 * 			ServerName:        pulumi.String("testserver"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.dbformysql.Database;
 * import com.pulumi.azurenative.dbformysql.DatabaseArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var database = new Database("database", DatabaseArgs.builder()
 *             .charset("utf8")
 *             .collation("utf8_general_ci")
 *             .databaseName("db1")
 *             .resourceGroupName("TestGroup")
 *             .serverName("testserver")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:dbformysql:Database db1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DBforMySQL/flexibleServers/{serverName}/databases/{databaseName}
 * ```
 * @property charset The charset of the database.
 * @property collation The collation of the database.
 * @property databaseName The name of the database.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property serverName The name of the server.
 */
public data class DatabaseArgs(
    public val charset: Output<String>? = null,
    public val collation: Output<String>? = null,
    public val databaseName: Output<String>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val serverName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.dbformysql.DatabaseArgs> {
    override fun toJava(): com.pulumi.azurenative.dbformysql.DatabaseArgs =
        com.pulumi.azurenative.dbformysql.DatabaseArgs.builder()
            .charset(charset?.applyValue({ args0 -> args0 }))
            .collation(collation?.applyValue({ args0 -> args0 }))
            .databaseName(databaseName?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .serverName(serverName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DatabaseArgs].
 */
@PulumiTagMarker
public class DatabaseArgsBuilder internal constructor() {
    private var charset: Output<String>? = null

    private var collation: Output<String>? = null

    private var databaseName: Output<String>? = null

    private var resourceGroupName: Output<String>? = null

    private var serverName: Output<String>? = null

    /**
     * @param value The charset of the database.
     */
    @JvmName("hdjplgvotyexemva")
    public suspend fun charset(`value`: Output<String>) {
        this.charset = value
    }

    /**
     * @param value The collation of the database.
     */
    @JvmName("qyjnkcikwvrohkmw")
    public suspend fun collation(`value`: Output<String>) {
        this.collation = value
    }

    /**
     * @param value The name of the database.
     */
    @JvmName("qkwpnheifgwsrkol")
    public suspend fun databaseName(`value`: Output<String>) {
        this.databaseName = value
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("vnvlsvcrnkmmfsvi")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value The name of the server.
     */
    @JvmName("ucknpkdrnpbpkarq")
    public suspend fun serverName(`value`: Output<String>) {
        this.serverName = value
    }

    /**
     * @param value The charset of the database.
     */
    @JvmName("gwwvsyatfbvmhdxb")
    public suspend fun charset(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.charset = mapped
    }

    /**
     * @param value The collation of the database.
     */
    @JvmName("rroibeompqenhheo")
    public suspend fun collation(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.collation = mapped
    }

    /**
     * @param value The name of the database.
     */
    @JvmName("cmncmpcxftbmcufy")
    public suspend fun databaseName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.databaseName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("aeqatnfpnntvlcft")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the server.
     */
    @JvmName("vfrfkuxeidrivjco")
    public suspend fun serverName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serverName = mapped
    }

    internal fun build(): DatabaseArgs = DatabaseArgs(
        charset = charset,
        collation = collation,
        databaseName = databaseName,
        resourceGroupName = resourceGroupName,
        serverName = serverName,
    )
}
